@@ -6,15 +6,15 @@ from ...base import PRAWBase
 from ..generator import ListingGenerator
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ...reddit.submission import Submission  # noqa: F401
+    import praw
 
 
 class SubmissionListingMixin(PRAWBase):
-    """Adds additional methods pertaining to Submission instances."""
+    """Adds additional methods pertaining to :class:`.Submission` instances."""
 
     def duplicates(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Submission"]:
+    ) -> Iterator["praw.models.Submission"]:
         """Return a :class:`.ListingGenerator` for the submission's duplicates.
 
         Additional keyword arguments are passed in the initialization of
@@ -24,12 +24,15 @@ class SubmissionListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           submission = reddit.submission(id="5or86n")
+            submission = reddit.submission("5or86n")
 
-           for duplicate in submission.duplicates():
-               # process each duplicate
+            for duplicate in submission.duplicates():
+                # process each duplicate
+                ...
 
-        .. seealso:: :meth:`~.upvote`
+        .. seealso::
+
+            :meth:`.upvote`
 
         """
         url = API_PATH["duplicates"].format(submission_id=self.id)
